SystemOrganization addCategory: #'Zinc-Resource-Meta-Tests'!

TestCase subclass: #ZnMimeTypeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Resource-Meta-Tests'!

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 19:59'!
testAsMimeType
	self assert: 'text/plain' asZnMimeType = ZnMimeType textPlain.
	self assert: ZnMimeType applicationOctetStream asZnMimeType = ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/6/2012 11:05'!
testCharset
	| mimeType |
	mimeType := ZnMimeType textPlain.
	self assert: mimeType charSet = 'utf-8'.
	mimeType charSet: 'ascii'.
	self assert: mimeType charSet = 'ascii'.
	mimeType clearCharSet.
	self assert: mimeType charSet isNil.
	mimeType setCharSetUTF8.
	self assert: mimeType charSet = 'utf-8'! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:51'!
testCopying
	| mimeType1 mimeType2 |
	mimeType1 := ZnMimeType textPlain.
	mimeType2 := ZnMimeType textPlain.
	self assert: mimeType1 = mimeType2.
	self assert: mimeType1 parameters = mimeType2 parameters.
	mimeType1 charSet: 'utf-8'.
	self assert: mimeType1 charSet = 'utf-8'.
	mimeType2 charSet: 'latin1'.
	self assert: mimeType2 charSet = 'latin1'.
	self assert: mimeType1 = mimeType2.
	self deny: mimeType1 parameters = mimeType2 parameters.
	self deny: mimeType1 charSet = mimeType2 charSet.
	! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:44'!
testDefault
	self assert: ZnMimeType default = ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:44'!
testIdentity
	self assert: ZnMimeType textPlain = ZnMimeType textPlain! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/6/2012 11:02'!
testParameters
	| mimeType |
	mimeType := ZnMimeType main: 'text' sub: 'plain'.
	self should: [ mimeType parameterAt: 'foo' ] raise: KeyNotFound.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = #none.
	mimeType parameterAt: 'foo' put: '1'.
	self assert: (mimeType parameterAt: 'foo') = '1'.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = '1'.
	mimeType removeParameter: 'foo'.
	mimeType removeParameter: 'bar'.
	self should: [ mimeType parameterAt: 'foo' ] raise: KeyNotFound.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = #none	! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testReading
	| mimeType |
	mimeType := ZnMimeType fromString: 'text/plain; charset=utf-8'.
	self assert: (mimeType main = 'text').
	self assert: (mimeType sub = 'plain').
	self assert: (mimeType charSet = 'utf-8').
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testWriting
	| mimeType |
	(mimeType := ZnMimeType main: 'text' sub: 'plain')
		charSet: 'utf-8'.
	self assert: mimeType printString = 'text/plain;charset=utf-8'.
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

TestCase subclass: #ZnMultiValueDictionaryTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Resource-Meta-Tests'!

!ZnMultiValueDictionaryTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testMultiValues
	| dictionary values keys |
	dictionary := ZnMultiValueDictionary new.
	dictionary at: 'foo' add: 1; at: 'foo' add: 2.
	self assert: (dictionary at: 'foo') = #(1 2).
	self assert: dictionary keys asArray = #('foo').
	values := OrderedCollection new.
	keys := OrderedCollection new.
	dictionary keysAndValuesDo: [ :key :value | keys add: key. values add: value ].
	self assert: values = (OrderedCollection with: 1 with: 2).
	self assert: keys = (OrderedCollection with: 'foo' with: 'foo')
	! !

!ZnMultiValueDictionaryTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2012 19:50'!
testTooManyEntries
	| dictionary |
	dictionary := ZnMultiValueDictionary new.
	self
		should: [ 1 to: dictionary limit + 1 do: [ :each | 
						dictionary at: each put: each ] ]
		raise: ZnTooManyDictionaryEntries! !

TestCase subclass: #ZnResourceMetaUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Resource-Meta-Tests'!

!ZnResourceMetaUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/17/2012 13:12'!
testDecodePercent
	self assert: (ZnResourceMetaUtils decodePercent: 'foo%20bar') equals: 'foo bar'.
	self should: [ ZnResourceMetaUtils decodePercent: 'foo%%bar' ] raise: ZnCharacterEncodingError ! !

!ZnResourceMetaUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/17/2012 13:11'!
testQueryParsing
	| string fields |
	string := 'foo=100&x=', (ZnPercentEncoder new encode: '/a b').
	fields := ZnResourceMetaUtils parseQueryFrom: string readStream.
	self assert: (fields at: 'foo') = '100'.
	self assert: (fields at: 'x') = '/a b'.
	! !

!ZnResourceMetaUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2012 21:00'!
testQueryWriting
	| fields string |
	(fields := Dictionary new)
		at: 'foo' put: '100';
		at: 'bar' put: 'a b'.
	string := String streamContents: [ :stream | 
		ZnResourceMetaUtils writeQueryFields: fields on: stream ].
	self assert: (string includesSubstring: 'foo=1').
	self assert: (string includesSubstring: 'bar=a%20b').! !

TestCase subclass: #ZnUrlTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Resource-Meta-Tests'!

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 20:43'!
testAsRelativeUrl
	| url |
	url := 'http://api.foo.com:8080/foo/bar.txt' asZnUrl.
	self assert: url hasHost.
	self assert: url hasScheme.
	self assert: url hasPort.
	self assert: url path equals: 'foo/bar.txt'.
	url := url asRelativeUrl.
	self deny: url hasHost.
	self deny: url hasScheme.
	self deny: url hasPort.
	self assert: url path equals: 'foo/bar.txt'.
	self assert: url asString equals: '/foo/bar.txt'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:05'!
testAuthority
	self assert: 'http://localhost:8080/foo/bar/doc.txt' asZnUrl authority = 'localhost:8080'.
	self assert: 'http://www.google.com?q=Smalltalk' asZnUrl authority = 'www.google.com'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/9/2012 16:33'!
testConvenienceMethods
	| baseUrl |
	baseUrl := 'http://api.host.com' asZnUrl.
	self 
		assert: baseUrl 
		equals: 'http://api.host.com' asZnUrl.
	self 
		assert: (baseUrl / 'doc' / 'file.html')
		equals: 'http://api.host.com/doc/file.html' asZnUrl.
	self 
		assert: (baseUrl / 'search' ? (#q -> 'Smalltalk') & (#lang -> #en))
		equals: 'http://api.host.com/search?q=Smalltalk&lang=en' asZnUrl.
	self 
		assert: baseUrl 
		equals: 'http://api.host.com' asZnUrl! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:13'!
testDefaultScheme
	| url |
	url := ZnUrl fromString: 'www.example.com/foo.html' defaultScheme: #http.  
	self assert: url hasScheme.
	self assert: url scheme = #http.
	self assert: url host = 'www.example.com'.
	self assert: url pathSegments = (OrderedCollection with: 'foo.html')
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:14'!
testDefaultSchemeAndPort
	| url |
	url := '' asZnUrl.
	self assert: url hasScheme not.
	self assert: url hasPort not.
	self assert: url port isNil.
	self assert: url scheme isNil.
	self assert: url schemeOrDefault = #http.
	self assert: url portOrDefault = 80
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:14'!
testDefaults
	| url |
	url := '' asZnUrl asZnUrlWithDefaults.
	self assert: url hasScheme.
	self assert: url hasPort.
	self assert: url scheme = #http.
	self assert: url port = 80
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/17/2011 10:29'!
testEncodedSlash
	self assert: 'http://example.com/foo//' asZnUrl pathPrintString = '/foo/'.
	self assert: 'http://example.com/foo//bar/' asZnUrl pathPrintString = '/foo/bar/'.
	self assert: 'http://example.com/foo//bar/file.txt' asZnUrl pathPrintString = '/foo/bar/file.txt'.

	self assert: 'http://example.com/foo/%2F' asZnUrl pathPrintString = '/foo/%2F'.
	self assert: 'http://example.com/foo/%2Fbar/' asZnUrl pathPrintString = '/foo/%2Fbar/'.
	self assert: 'http://example.com/foo/%2F/bar/' asZnUrl pathPrintString = '/foo/%2F/bar/'.
	self assert: 'http://example.com/foo/%2Ffoo.txt' asZnUrl pathPrintString = '/foo/%2Ffoo.txt'.

! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/14/2013 11:42'!
testFileUrl
	| url |
	url := 'file://localhost/users/Sven/Desktop/foo.txt' asZnUrl.
	self assert: url isFile.
	self assert: url host equals: 'localhost'.
	self assert: url pathSegments equals: #( 'users' 'Sven' 'Desktop' 'foo.txt' ) asOrderedCollection ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 20:53'!
testInContextOf
	| baseUrl url |
	baseUrl := 'http://zn.stfx.eu/foo.txt' asZnUrl.
	url := ZnUrl new addPathSegment: 'bar.txt'.
	self assert: (url inContextOf: baseUrl) equals: 'http://zn.stfx.eu/bar.txt' asZnUrl.
	"The following holds for all URLs"
	self assert: (baseUrl asRelativeUrl inContextOf: baseUrl) equals: baseUrl! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:42'!
testIsSlash
	self assert: '' asZnUrl isSlash.
	self assert: '/' asZnUrl isSlash.
	self assert: '/foo' asZnUrl isSlash not.
	self assert: 'http://host/foo' asZnUrl isSlash not.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/13/2011 10:44'!
testLocalHost
	self assert: 'http://localhost:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://127.0.0.1:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://LOCALHOST:8080/foo' asZnUrl isLocalHost.
	self deny: 'http://zn.stx.eu' asZnUrl isLocalHost.
	self deny: '' asZnUrl isLocalHost.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 14:55'!
testMissingScheme
	| url |
	url := 'www.example.com' asZnUrl.
	self assert: url hasHost not.
	self assert: url pathSegments = (OrderedCollection with: 'www.example.com')
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:20'!
testParsePathOnly
	| url |
	url := '/images/foo.png?size=large#center' asZnUrl.
	self assert: url hasScheme not.
	self assert: url hasHost not.
	self assert: url hasPort not.
	self assert: url isAbsolute not.
	self assert: url pathSegments = (OrderedCollection with: 'images' with: 'foo.png' ).
	self assert: url firstPathSegment = 'images'.
	self assert: url lastPathSegment = 'foo.png'.
	self assert: url hasQuery.
	self assert: (url queryAt: 'size') = 'large'.
	self assert: url hasFragment.
	self assert: url fragment = 'center'  ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 12:17'!
testParsingEmpty
	| url |
	url := ZnUrl fromString: ''.
	self assert: url isEmpty.
	url := ZnUrl fromString: '/'.
	self assert: url isEmpty.
	url := ZnUrl fromString: '//./foo/../'.
	self assert: url isEmpty! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:36'!
testParsingEscape
	| url |
	url := ZnUrl fromString: 'http://localhost/foo%62%61%72'.
	self assert: url firstPathSegment = 'foobar'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/14/2013 11:38'!
testParsingSimple
	| url |
	url := ZnUrl fromString: 'http://www.example.com:8080/foo/bar/baz.txt?x=1&y=2#m1'.
	self assert: url scheme = #http.
	self assert: url host = 'www.example.com'.
	self assert: url port = 8080.
	self assert: url hasPath.
	self assert: url isFilePath.
	self assert: url hasQuery.
	self assert: url hasFragment.
	self assert: url fragment = 'm1'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/17/2012 13:12'!
testParsingWrongEscape
	self should: [ ZnUrl fromString: 'http://foo:8080/foo%%bar' ] raise: ZnCharacterEncodingError ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/17/2012 13:12'!
testParsingWrongEscapeQuery
	self should: [ ZnUrl fromString: 'http://foo:8080/foo?%%bar=1' ] raise: ZnCharacterEncodingError ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:28'!
testParsingWrongPort
	self should: [ ZnUrl fromString: 'http://foo:bar' ] raise: ZnPortNotANumber   ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/30/2013 17:25'!
testParsingWrongScheme
	| url |
	url := ZnUrl fromString: 'git://user@foo.com/bar'.
	self assert: url scheme equals: #git.
	self assert: url username equals: 'user'.
	self assert: url host equals: 'foo.com'.
	self assert: url path equals: 'bar'.
	self should: [ url enforceKnownScheme ] raise: ZnUnknownScheme ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 20:43'!
testPathRemoval
	| url |
	url := 'http://api.foo.com:8080/foo/123/bar.txt?x=1&y=2' asZnUrl.
	self assert: url path equals: 'foo/123/bar.txt'.
	url removeFirstPathSegment.
	self assert: url path equals: '123/bar.txt'.
	url removeLastPathSegment.
	self assert: url path equals: '123'.
	url clearPath.
	self deny: url hasPath.
	self assert: (url queryAt: #x) equals: '1'.
	self assert: (url queryAt: #y) equals: '2'.
	self assert: url scheme equals: #http.
	self assert: url host equals: 'api.foo.com'.
	self assert: url port equals: 8080! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/14/2013 11:38'!
testPrintingSimple
	| url |
	(url := ZnUrl new)
		scheme: #http;
		host: 'www.seaside.st';
		port: 8080;
		addPathSegment: 'example';
		addPathSegment: 'foo.html';
		queryAt: 'q' put: '100';
		fragment: 'mark'.
	self assert: url authority = 'www.seaside.st:8080'.
	self assert: url isAbsolute.
	self assert: url isFilePath.
	self assert: url printString = 'http://www.seaside.st:8080/example/foo.html?q=100#mark'.
	self assert: url file = 'foo.html'.
	self assert: url directory = 'example'.
	self assert: url pathPrintString = '/example/foo.html'.
	self assert: url pathQueryFragmentPrintString = '/example/foo.html?q=100#mark'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:26'!
testQuery
	| url |
	url := 'http://foo.com/test?q' asZnUrl.
	self assert: url printString = 'http://foo.com/test?q'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/13/2011 14:16'!
testQueryEncoding
	| url |
	url := 'http://www.google.com' asZnUrl.
	url addPathSegment: 'some encoding here'.
	url queryAt: 'and some encoding' put: 'here, too'.
	self assert: url printString = 'http://www.google.com/some%20encoding%20here?and%20some%20encoding=here%2C%20too'.
	self assert: url path =  'some encoding here'.
	self assert: (url queryAt: 'and some encoding') = 'here, too'
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 20:11'!
testQueryManipulation
	| url |
	url := 'http://www.google.com/?one=1&two=2' asZnUrl.
	url queryAt: 'three' put: '3'.
	url queryRemoveKey: 'one'.
	self assert: url queryKeys sorted = #(three two).
	self assert: (url queryAt: 'two') = '2'.
	self assert: (url queryAt: 'three') = '3'.
	url queryRemoveAll.
	self deny: url hasQuery! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:10'!
testRelative
	| url |
	url := 'http://api.foo.com:8080' asZnUrl.
	self assert: url isAbsolute.
	url parseFrom: '/user/1?format=full'.
	self assert: url printString = 'http://api.foo.com:8080/user/1?format=full'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/24/2012 11:44'!
testRetrieveContents
	| numbers |
	numbers := 'http://zn.stfx.eu/zn/numbers.txt' asZnUrl retrieveContents.
	numbers := numbers lines collect: [ :each | each asInteger ].
	self assert: (numbers allSatisfy: [ :each | each isInteger ]).
	self should: [ 'http://zn.stfx.eu/zn/numbers-wrong.txt' asZnUrl retrieveContents ] raise: Error! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/30/2013 16:45'!
testUserInfo
	| url |
	url := 'http://john:secret@www.foo.com:8888/foo/bar.txt' asZnUrl.
	self assert: url scheme equals: #http.
	self assert: url username equals: 'john'.
	self assert: url password equals: 'secret'.
	self assert: url host equals: 'www.foo.com'.
	self assert: url port equals: 8888.
	self assert: url pathSegments asArray equals: #('foo' 'bar.txt').
	url := 'http://john@www.foo.com:8888/foo/bar.txt' asZnUrl.
	self assert: url scheme equals: #http.
	self assert: url username equals: 'john'.
	self deny: url hasPassword.
	self assert: url host equals: 'www.foo.com'.
	self assert: url port equals: 8888.
	self assert: url pathSegments asArray equals: #('foo' 'bar.txt')! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/6/2013 18:21'!
testWindowsFileUrl
	| url |
	url := 'file://localhost/C:/users/Sven/Desktop/foo.txt' asZnUrl.
	self assert: url isFile.
	self assert: url host equals: 'localhost'.
	self assert: url pathSegments equals: #( 'C:' 'users' 'Sven' 'Desktop' 'foo.txt' ) asOrderedCollection ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:57'!
testWriteUrlPathQueryFragmentOfOn
	| string |
	string := String streamContents: [ :stream |
		'http://host:7777/foo/bar/doc.txt?x=1#mark' asZnUrl printPathQueryFragmentOn:  stream ].
	self assert: string = '/foo/bar/doc.txt?x=1#mark'! !
